.. leap-frontend documentation master file, created by
   sphinx-quickstart on Fri Sep 20 15:30:59 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome
=======

.. toctree::
   :maxdepth: 2
   :caption: Leap frontend's documentation:

   usage/installation
   changelog
   usage/faq

.. toctree::
   :maxdepth: 2
   :caption: Verilog I/O:

   modules/io

.. toctree::
   :maxdepth: 2
   :caption: Graph Representation:

   modules/netlist